@@ -32,7 +32,7 @@
 #define SYNCTEX_GZ_EXT ".synctex.gz"
 #define SYNCTEX_EXT ".synctex"
 
-PdfViewer::PdfViewer( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString psize,const QKeySequence edfocus,const QString SpellLang,QWidget* parent, Qt::WFlags flags)
+PdfViewer::PdfViewer( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString psize,const QKeySequence edfocus,const QString SpellLang, const qreal startScale, QWidget* parent, Qt::WFlags flags)
     : QMainWindow( parent, flags )
 {
 setWindowTitle("Texmaker : pdf preview");
@@ -69,7 +69,7 @@ paper_size=psize;
 lastFile=fileName;
 lastPage=1;
 lastHpos=0;
-lastScale=0.1;
+lastScale=startScale;
 fileLoaded=false;
 currentPage=1;
 doc = 0;
@@ -361,8 +361,9 @@ if (doc!=0)
     else ShowStructure();
     gotoPage(currentPage);
     disconnect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
-    if (scrollArea->horizontalScrollBar()->isVisible())  scrollArea->horizontalScrollBar()->setValue(lastHpos);
+    if (scrollArea->horizontalScrollBar()->isVisible())  {QTimer::singleShot( 500,this, SLOT(jumptoHpos()) );}
     connect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
+    emit sendFocusToEditor();
     } 
     else 
       {
@@ -540,7 +541,7 @@ listPdfWidgetsStatus.replace(page,1);
   scrollArea->update();
 pageMutex.unlock();
 disconnect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
-if (scrollArea->horizontalScrollBar()->isVisible())  scrollArea->horizontalScrollBar()->setValue(lastHpos);
+if (scrollArea->horizontalScrollBar()->isVisible())  {QTimer::singleShot( 500,this, SLOT(jumptoHpos()) );}
 connect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
 }
 
@@ -1133,6 +1134,10 @@ QString gs="none";
 QString gstemp=gswin32c_command;
 gstemp.remove("\"");
 if (QFileInfo(gstemp).exists()) gs=gstemp;
+else if (QFileInfo("C:/Program Files/gs/gs9.05/bin/gswin32c.exe").exists()) gs="C:/Program Files/gs/gs9.05/bin/gswin32c.exe";
+else if (QFileInfo("C:/Program Files (x86)/gs/gs9.05/bin/gswin32c.exe").exists()) gs="C:/Program Files (x86)/gs/gs9.05/bin/gswin32c.exe";
+else if (QFileInfo("C:/Program Files/gs/gs9.04/bin/gswin32c.exe").exists()) gs="C:/Program Files/gs/gs9.04/bin/gswin32c.exe";
+else if (QFileInfo("C:/Program Files (x86)/gs/gs9.04/bin/gswin32c.exe").exists()) gs="C:/Program Files (x86)/gs/gs9.04/bin/gswin32c.exe";
 else if (QFileInfo("C:/Program Files/gs/gs9.02/bin/gswin32c.exe").exists()) gs="C:/Program Files/gs/gs9.02/bin/gswin32c.exe";
 else if (QFileInfo("C:/Program Files (x86)/gs/gs9.02/bin/gswin32c.exe").exists()) gs="C:/Program Files (x86)/gs/gs9.02/bin/gswin32c.exe";
 else if (QFileInfo("C:/Program Files/gs/gs9.00/bin/gswin32c.exe").exists()) gs="C:/Program Files/gs/gs9.00/bin/gswin32c.exe";
@@ -1208,7 +1213,7 @@ if(!printer.printerName().isEmpty())
   QStringList args;
   args << "lp";
   if (!printer.printerName().contains(" ")) args << QString("-d %1").arg(printer.printerName());//.replace(" ","_"));
-  args << QString("-n %1").arg(printer.numCopies());
+  args << QString("-n %1").arg(printer.copyCount());
 //  args << QString("-t \"%1\"").arg(printer.docName());
   args << QString("-P %1-%2").arg(firstPage).arg(lastPage);
   switch(printer.duplex()) 
@@ -1262,6 +1267,11 @@ void PdfViewer::setKeyEditorFocus(QKeySequence s)
 KeySequenceEditorFocus=s;
 }
 
+void PdfViewer::setGSCommand(QString c)
+{
+gswin32c_command=c;
+}
+
 void PdfViewer::keyPressEvent ( QKeyEvent * e ) 
 {
 int qtKeyCode = e->key();
@@ -1410,3 +1420,7 @@ void PdfViewer::setHpos(int pos)
 lastHpos=pos;
 }
 
+void PdfViewer::jumptoHpos()
+{
+scrollArea->horizontalScrollBar()->setValue(lastHpos);
+}
