@@ -33,7 +33,7 @@
 #define SYNCTEX_GZ_EXT ".synctex.gz"
 #define SYNCTEX_EXT ".synctex"
 
-PdfViewerWidget::PdfViewerWidget( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString psize,const QKeySequence edfocus,const QString SpellLang ,QWidget* parent)
+PdfViewerWidget::PdfViewerWidget( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString psize,const QKeySequence edfocus,const QString SpellLang, const qreal startScale ,QWidget* parent)
     : QWidget( parent)
 {
 spell_lang=SpellLang;
@@ -46,7 +46,7 @@ paper_size=psize;
 lastFile=fileName;
 lastPage=1;
 lastHpos=0;
-lastScale=0.1;
+lastScale=startScale;
 fileLoaded=false;
 currentPage=1;
 doc = 0;
@@ -337,9 +337,11 @@ if (doc!=0)
     setWindowTitle(QFileInfo(fn).fileName());
     clearHistory();
     gotoPage(currentPage);
+    
     disconnect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
-    if (scrollArea->horizontalScrollBar()->isVisible())  scrollArea->horizontalScrollBar()->setValue(lastHpos);
+    if (scrollArea->horizontalScrollBar()->isVisible())  {QTimer::singleShot( 500,this, SLOT(jumptoHpos()) );}
     connect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
+    emit sendFocusToEditor();
     } 
     else 
       {
@@ -521,8 +523,9 @@ int pos=0;
 listPdfWidgetsStatus.replace(page,1);
   scrollArea->update();
 pageMutex.unlock();
+
 disconnect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
-if (scrollArea->horizontalScrollBar()->isVisible())  scrollArea->horizontalScrollBar()->setValue(lastHpos);
+if (scrollArea->horizontalScrollBar()->isVisible())  {QTimer::singleShot( 500,this, SLOT(jumptoHpos()) );}
 connect(scrollArea,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
 }
 
@@ -1117,6 +1120,10 @@ QString gs="none";
 QString gstemp=gswin32c_command;
 gstemp.remove("\"");
 if (QFileInfo(gstemp).exists()) gs=gstemp;
+else if (QFileInfo("C:/Program Files/gs/gs9.05/bin/gswin32c.exe").exists()) gs="C:/Program Files/gs/gs9.05/bin/gswin32c.exe";
+else if (QFileInfo("C:/Program Files (x86)/gs/gs9.05/bin/gswin32c.exe").exists()) gs="C:/Program Files (x86)/gs/gs9.05/bin/gswin32c.exe";
+else if (QFileInfo("C:/Program Files/gs/gs9.04/bin/gswin32c.exe").exists()) gs="C:/Program Files/gs/gs9.04/bin/gswin32c.exe";
+else if (QFileInfo("C:/Program Files (x86)/gs/gs9.04/bin/gswin32c.exe").exists()) gs="C:/Program Files (x86)/gs/gs9.04/bin/gswin32c.exe";
 else if (QFileInfo("C:/Program Files/gs/gs9.02/bin/gswin32c.exe").exists()) gs="C:/Program Files/gs/gs9.02/bin/gswin32c.exe";
 else if (QFileInfo("C:/Program Files (x86)/gs/gs9.02/bin/gswin32c.exe").exists()) gs="C:/Program Files (x86)/gs/gs9.02/bin/gswin32c.exe";
 else if (QFileInfo("C:/Program Files/gs/gs9.00/bin/gswin32c.exe").exists()) gs="C:/Program Files/gs/gs9.00/bin/gswin32c.exe";
@@ -1192,7 +1199,7 @@ if(!printer.printerName().isEmpty())
   QStringList args;
   args << "lp";
   if (!printer.printerName().contains(" ")) args << QString("-d %1").arg(printer.printerName());//.replace(" ","_"));
-  args << QString("-n %1").arg(printer.numCopies());
+  args << QString("-n %1").arg(printer.copyCount());
 //  args << QString("-t \"%1\"").arg(printer.docName());
   args << QString("-P %1-%2").arg(firstPage).arg(lastPage);
   switch(printer.duplex()) 
@@ -1247,6 +1254,11 @@ void PdfViewerWidget::setKeyEditorFocus(QKeySequence s)
 KeySequenceEditorFocus=s;
 }
 
+void PdfViewerWidget::setGSCommand(QString c)
+{
+gswin32c_command=c;
+}
+
 void PdfViewerWidget::keyPressEvent ( QKeyEvent * e ) 
 {
 int qtKeyCode = e->key();
@@ -1388,3 +1400,7 @@ void PdfViewerWidget::setHpos(int pos)
 lastHpos=pos;
 }
 
+void PdfViewerWidget::jumptoHpos()
+{
+scrollArea->horizontalScrollBar()->setValue(lastHpos);
+}
